mag_calc
--------

.. currentmodule:: eqcorrscan.utils.mag_calc
.. automodule:: eqcorrscan.utils.mag_calc

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       amp_pick_event
       calc_b_value
       calc_max_curv
       dist_calc
       svd_moments
       relative_amplitude
       relative_magnitude

    .. comment to end block

    Private Functions
    -----------------
    Note that these functions are not designed for public use and may change
    at any point.

    .. autosummary::
       :toctree: autogen
       :nosignatures:

       _sim_WA
       _pairwise
       _max_p2t
       _find_resp
       _GSE2_PAZ_read

    .. comment to end block
